*-- Before you integrate FRX2Any into your VFP application you should realize that FRX2Any
*-- requires GDIPlus.DLL which is freely available and can be installed on Win98 and higher.
*-- If you have not installed WinXP or .NET framework then you can download this DLL from
*-- http://www.microsoft.com/msdownload/platformsdk/sdkupdate/psdkredist.htm
*-- or
*-- http://www.dll-files.com/dllindex/dll-files.shtml?gdiplus


***************************************************************************************************************************
*-- OutPut options
***************************************************************************************************************************
#DEFINE cnOUTPUT_SCREEN			         				1
#DEFINE cnOUTPUT_PRINT			         				2
#DEFINE cnOUTPUT_EMAIL			         				3
#DEFINE cnOUTPUT_FILE		 	         				4

***************************************************************************************************************************
*-- Enumeration type for the various axis types that are available
***************************************************************************************************************************
#DEFINE cnCHART_AXIS_TYPE_LINERAL						0
#DEFINE cnCHART_AXIS_TYPE_LOG							1
#DEFINE cnCHART_AXIS_TYPE_DATE							2
#DEFINE cnCHART_AXIS_TYPE_TEXT							3
#DEFINE cnCHART_AXIS_TYPE_ORDINAL						4

***************************************************************************************************************************
*-- Enumeration type that defines the available types of BarItem
***************************************************************************************************************************
#DEFINE cnCHART_BARITEM_TYPE_CLUSTER					0
#DEFINE cnCHART_BARITEM_TYPE_OVERLAY					1
#DEFINE cnCHART_BARITEM_TYPE_SORTEDOVERLAY				2
#DEFINE cnCHART_BARITEM_TYPE_STACK						3
#DEFINE cnCHART_BARITEM_TYPE_PERCENTSTACK				4

***************************************************************************************************************************
*-- Enumeration type for the various symbol shapes that are available
***************************************************************************************************************************
#DEFINE cnCHART_SYMBOL_TYPE_SQUARE						0
#DEFINE cnCHART_SYMBOL_TYPE_DIAMOND						1
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE					2
#DEFINE cnCHART_SYMBOL_TYPE_CIRCLE						3
#DEFINE cnCHART_SYMBOL_TYPE_XCROSS						4
#DEFINE cnCHART_SYMBOL_TYPE_PLUS						5
#DEFINE cnCHART_SYMBOL_TYPE_STAR						6
#DEFINE cnCHART_SYMBOL_TYPE_TRIANGLE_DOWN				7

***************************************************************************************************************************
*-- LinearGradient Mode
***************************************************************************************************************************
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_HORIZONTAL			0
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_VERTICAL			1
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL	2
#DEFINE cnGDIPLUS_LINEARGRADIENTMODE_BACKWARDDIAGONAL	3

***************************************************************************************************************************
*-- Enumeration type that defines how a curve is drawn
***************************************************************************************************************************
#DEFINE cnCHART_LINE_STEP_TYPE_FORWARD					0
#DEFINE cnCHART_LINE_STEP_TYPE_REARWARD					1
#DEFINE cnCHART_LINE_STEP_TYPE_NONE						2


LOCAL laX
LOCAL laY

LOCAL loChart
LOCAL loFile
LOCAL loChartCurve

LOCAL lcOutPutFileName
LOCAL lcOutPutFilePath
LOCAL lcReportFullName


CD LEFT(SYS(16,0), RAT('\', SYS(16,0)))

SET PATH TO  ..\..\..\


lcReportFullName = FULLPATH('..\..\Reports\ChartInTitleBand.FRX')

IF !FILE(lcReportFullName)
	=MESSAGEBOX('File ' + lcReportFullName + ' does not exist.', 16, 'Error')

ELSE

	lcOutPutFileName = JUSTSTEM(lcReportFullName)
	lcOutPutFilePath = JUSTPATH(SYS(16,0)) + '\OutPut\'

	SET CLASSLIB TO FRX2Any IN FRX2Any.APP ALIAS FRX2Any

	loFile = CREATEOBJECT('FRX2Any.PDFFile')

	IF TYPE('loFile') = 'O'

		WITH loFile

*-- Unlock FRX2Any
			.UNLOCK('xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx-xxxxxx')

*-- NOTE: loFile.cExportFileName should not include file extension. For example: loFile.cExportFileName = 'ReportOutput'
			.cExportFileName = lcOutPutFileName

*-- NOTE: loFile.cSaveFolder should contain only path to the output file. For example: loFile.cSaveFolder = 'c:\MyApp\MyOutPut\'
			.cSaveFolder     = lcOutPutFilePath

*-- Specifies that output file will be displayed after creation
			.nOutPutType     = cnOUTPUT_SCREEN
			
*-- Chart will be drawn in the Title band.
*-- 'Chart place keeper' - is an unique name of the Chart, which must be placed in a Comment field of the Box oject
*-- used as a 'place keeper' and which will be replaced by Chart.
			loChart = .AddChart('Chart place keeper')

*-- Specify Chart's properties
*-- For description of all Chart's properties and methods, please see FRX2Any help file.
			WITH loChart.oPanel
*-- Set the main Title of the Chart
				.cTitle = 'Semurg Enterprise' + CHR(10) + 'Production report (2000 - 2004)'

				WITH .oPanelBorder
					.lVisible   = .F.
				ENDWITH


				WITH .oFontSpec
					.cFamily   = 'Arial Black'
				ENDWITH

*-- Set a background color to the Chart panel frame
				WITH .oPanelFill
*-- Create a linear gradient color-fill
					.SetGradientFill(RGB(255,255,255), RGB(208,224,244), 2)
				ENDWITH

*-- Set a background color to the axis frame
				WITH .oAxisFill
*-- Create a linear gradient color-fill
					.SetGradientFill(RGB(255,255,255), RGB(249, 253, 200), 2)
				ENDWITH

*-- Set Title for X axis
				WITH .oXAxis
*-- Set the X axis title.
					.cTitle 	 = 'Time, days' + CHR(10) + '(Since Project Startup)'

					WITH .oScaleFontSpec
						.nAngle = 315
						.nSize  = 10
					ENDWITH

				ENDWITH

*-- Set Title for Y axis
				WITH .oYAxis
*-- Set the Y axis title.
					.cTitle = 'Semurg Enterprise' + CHR(10) + '(units/hour)'

					WITH .oScaleFontSpec
						.nAngle = 135
						.nSize  = 10
					ENDWITH

				ENDWITH


*-- Add a Curve Item with Circle symbols, and 'Larry' in the legend

*-- Make up some random data points
				DIMENSION laX[10] AS INTEGER

				laX[1]  = 72
				laX[2]  = 205
				laX[3]  = 305
				laX[4]  = 405
				laX[5]  = 505
				laX[6]  = 605
				laX[7]  = 705
				laX[8]  = 805
				laX[9]  = 905
				laX[10] = 995

				DIMENSION laY[10]
				laY[1]  = 25
				laY[2]  = 15
				laY[3]  = 55
				laY[4]  = 45
				laY[5]  = 35
				laY[6]  = 65
				laY[7]  = 95
				laY[8]  = 25
				laY[9]  = 48
				laY[10] = 75

				loChartCurve = .AddCurve('Larry', @laX, @laY, RGB(255,55,205), cnCHART_SYMBOL_TYPE_CIRCLE)

				IF !ISNULL(loChartCurve)

					WITH loChartCurve

						WITH .oLine

							.nWidth  = 1.5

							WITH .oFill
								.SetGradientFill(RGB(255,255,255), RGB(255,155,205), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL, 200)
							ENDWITH

						ENDWITH

						WITH .oSymbol
*-- Set the size of the Symbol, value Size in pixels
							.nSize = 10

							WITH .oFill
*-- Create a linear gradient color-fill
								.SetSolidFill(RGB(255, 255, 255))
							ENDWITH

						ENDWITH

					ENDWITH

				ENDIF


*-- Add a Curve Item with Triangle symbols, and 'Oktam' in the legend

*-- Make up some random data points
				DIMENSION laX[10] AS INTEGER

				laX[1]  = 310
				laX[2]  = 455
				laX[3]  = 535
				laX[4]  = 555
				laX[5]  = 615
				laX[6]  = 645
				laX[7]  = 745
				laX[8]  = 825
				laX[9]  = 910
				laX[10] = 980

				DIMENSION laY[10]
				laY[1]  = 23
				laY[2]  = 15
				laY[3]  = 76
				laY[4]  = 40
				laY[5]  = 07
				laY[6]  = 60
				laY[7]  = 89
				laY[8]  = 25
				laY[9]  = 48
				laY[10] = 96

				loChartCurve = .AddCurve('Oktam', @laX, @laY, RGB(52, 119, 30), cnCHART_SYMBOL_TYPE_TRIANGLE)

				IF !ISNULL(loChartCurve)

					WITH loChartCurve

						WITH .oLine

							.nWidth    = 1.5
							.nStepType = cnCHART_LINE_STEP_TYPE_REARWARD

							WITH .oFill
								.SetGradientFill(RGB(255,255,255), RGB(52, 119, 30), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL, 200)
							ENDWITH

						ENDWITH

						WITH .oSymbol
*-- Set the size of the Symbol, value Size in pixels
							.nSize = 10

							WITH .oFill
*-- Create a linear gradient color-fill
								.SetSolidFill(RGB(255, 255, 255))
							ENDWITH

						ENDWITH

					ENDWITH

				ENDIF

*-- Add a Curve Item with Triangle down symbols, and 'Philipp' in the legend

*-- Make up some random data points
				DIMENSION laX[10] AS INTEGER

				laX[1]  = 110
				laX[2]  = 355
				laX[3]  = 435
				laX[4]  = 455
				laX[5]  = 515
				laX[6]  = 545
				laX[7]  = 645
				laX[8]  = 725
				laX[9]  = 810
				laX[10] = 880

				DIMENSION laY[10]
				laY[1]  = 33
				laY[2]  = 25
				laY[3]  = 86
				laY[4]  = 50
				laY[5]  = 17
				laY[6]  = 70
				laY[7]  = 99
				laY[8]  = 35
				laY[9]  = 58
				laY[10] = 76

				loChartCurve = .AddCurve('Philipp', @laX, @laY, RGB(14, 41, 154), cnCHART_SYMBOL_TYPE_TRIANGLE_DOWN)

				IF !ISNULL(loChartCurve)

					WITH loChartCurve

						WITH .oLine

							.nWidth    = 1.5
							.nStepType = cnCHART_LINE_STEP_TYPE_FORWARD

							WITH .oFill
								.SetGradientFill(RGB(255,255,255), RGB(14, 41, 154), cnGDIPLUS_LINEARGRADIENTMODE_FORWARDDIAGONAL, 200)
							ENDWITH

						ENDWITH

						WITH .oSymbol
*-- Set the size of the Symbol, value Size in pixels
							.nSize = 10

							WITH .oFill
*-- Create a linear gradient color-fill
								.SetSolidFill(RGB(255, 255, 255))
							ENDWITH

						ENDWITH

					ENDWITH

				ENDIF

			ENDWITH

			
			.SAVE(lcReportFullName)

			.RELEASE()


		ENDWITH

	ENDIF

ENDIF
